@@ -15,15 +15,15 @@ class Substitutable:
     # Names of converters to apply after substitution
     converters: typing.List[str] = field(default_factory=list)
 
-    @classmethod
-    def parse_substitution(cls, sub_text: str) -> typing.Union[str, typing.List[str]]:
+    @staticmethod
+    def parse_substitution(sub_text: str) -> typing.Union[str, typing.List[str]]:
         """Parse substitution text into token list or string."""
         sub_text = sub_text.strip()
 
-        if sub_text.startswith("("):
+        if sub_text[:1] == "(":
             sub_text = sub_text[1:]
 
-        if sub_text.endswith(")"):
+        if sub_text[-1:] == ")":
             sub_text = sub_text[:-1]
 
         if " " in sub_text:
@@ -122,10 +122,8 @@ class ParseMetadata:
 class Sentence(Sequence):
     """Sequence representing a complete sentence template."""
 
-    @classmethod
-    def parse(
-        cls, text: str, metadata: typing.Optional[ParseMetadata] = None
-    ) -> "Sentence":
+    @staticmethod
+    def parse(text: str, metadata: typing.Optional[ParseMetadata] = None) -> "Sentence":
         """Parse a single sentence."""
         s = Sentence(text=text)
         parse_expression(s, text, metadata=metadata)
@@ -149,10 +147,8 @@ class Rule:
     public: bool = False
     text: str = ""
 
-    @classmethod
-    def parse(
-        cls, text: str, metadata: typing.Optional[ParseMetadata] = None
-    ) -> "Rule":
+    @staticmethod
+    def parse(text: str, metadata: typing.Optional[ParseMetadata] = None) -> "Rule":
         """Parse a single rule."""
         # public <RuleName> = rule body;
         # <RuleName> = rule body;
@@ -266,19 +262,20 @@ def split_words(text: str) -> typing.Iterable[Expression]:
         tokens.append(token)
 
     for token in tokens:
-        if token.startswith("$"):
-            if ":" in token:
+        if token[:1] == "$":
+            slot_name = token[1:]
+            if ":" in slot_name:
                 # Slot with substitutions
-                lhs, rhs = token[1:].split(":", maxsplit=1)
+                slot_name, substitution = slot_name.split(":", maxsplit=1)
                 yield SlotReference(
                     text=token,
-                    slot_name=lhs,
-                    substitution=Substitutable.parse_substitution(rhs),
+                    slot_name=slot_name,
+                    substitution=Substitutable.parse_substitution(substitution),
                 )
             else:
                 # Slot without substitutions
-                yield SlotReference(text=token, slot_name=token[1:])
-        elif ":" in token or "!" in token:
+                yield SlotReference(text=token, slot_name=slot_name)
+        else:
             word = Word(text=token)
 
             if "!" in token:
@@ -296,9 +293,6 @@ def split_words(text: str) -> typing.Iterable[Expression]:
                 word.substitution = Substitutable.parse_substitution(rhs)
 
             yield word
-        else:
-            # With without substitution
-            yield Word(text=token)
 
 
 def parse_expression(
@@ -554,20 +548,19 @@ def parse_expression(
                 tag.tag_text = text[current_index + 1 : next_index - 1]
 
                 # Handle substitution/converter(s)
-                if ":" in tag.tag_text or "!" in tag.tag_text:
-                    if "!" in tag.tag_text:
-                        # Word with converter(s)
-                        # e.g., twenty:20!int
-                        parts = tag.tag_text.split("!")
-                        tag.tag_text = parts[0]
-                        tag.converters = parts[1:]
+                if "!" in tag.tag_text:
+                    # Word with converter(s)
+                    # e.g., twenty:20!int
+                    parts = tag.tag_text.split("!")
+                    tag.tag_text = parts[0]
+                    tag.converters = parts[1:]
 
-                    if ":" in tag.tag_text:
-                        # Word with substitution
-                        # e.g., twenty:20
-                        lhs, rhs = tag.tag_text.split(":", maxsplit=1)
-                        tag.tag_text = lhs
-                        tag.substitution = Substitutable.parse_substitution(rhs)
+                if ":" in tag.tag_text:
+                    # Word with substitution
+                    # e.g., twenty:20
+                    lhs, rhs = tag.tag_text.split(":", maxsplit=1)
+                    tag.tag_text = lhs
+                    tag.substitution = Substitutable.parse_substitution(rhs)
 
                 last_taggable.tag = tag
             elif c == "|":
