@@ -166,8 +166,17 @@ class IniJsgfTestCase(unittest.TestCase):
             minute,
             Sentence(
                 text="2 | 3",
-                type=SequenceType.ALTERNATIVE,
-                items=[Word("two", substitution="2"), Word("three", substitution="3")],
+                type=SequenceType.GROUP,
+                items=[
+                    Sequence(
+                        text="2 | 3",
+                        type=SequenceType.ALTERNATIVE,
+                        items=[
+                            Word("two", substitution="2"),
+                            Word("three", substitution="3"),
+                        ],
+                    )
+                ],
             ),
         )
 
@@ -194,9 +203,15 @@ class IniJsgfTestCase(unittest.TestCase):
                                 items=[
                                     Sequence(
                                         text="page | layer",
-                                        type=SequenceType.ALTERNATIVE,
-                                        items=[Word("page"), Word("layer")],
+                                        type=SequenceType.GROUP,
                                         tag=Tag(tag_text="layout"),
+                                        items=[
+                                            Sequence(
+                                                text="page | layer",
+                                                type=SequenceType.ALTERNATIVE,
+                                                items=[Word("page"), Word("layer")],
+                                            )
+                                        ],
                                     ),
                                     Word(""),
                                 ],
@@ -207,6 +222,27 @@ class IniJsgfTestCase(unittest.TestCase):
             },
         )
 
+    def test_rule_with_same_name(self):
+        """Ensure referenced rule names don't conflict with local names."""
+
+        ini_text = """
+        [Test1]
+        rule = is a test
+        this <rule>
+
+        [Test2]
+        rule = <Test1.rule>
+        this <rule>
+        """
+
+        _intents = parse_ini(ini_text)
+        intents, replacements = split_rules(_intents)
+
+        # Walk all sentences to make sure there's no infinite recursion
+        for intent, sentences in intents.items():
+            for sentence in sentences:
+                walk_expression(sentence, lambda x: x, replacements)
+
 
 # -----------------------------------------------------------------------------
 
